"use client";

import React, { useEffect, useState, Suspense } from 'react';
import { useSearchParams, useRouter } from 'next/navigation';
import HeroAfric from '@/app/components/HeroAfric';
import AfriqWatchButton from '@/app/components/AfriqWatchButton';
import RelatedAfricanMovies from '@/app/components/RelatedAfricanMovies';
import AdSense from '@/app/components/AdSense'; // Import AdSense component
import Head from 'next/head';

interface YouTubeMovie {
  id: string;
  title: string;
  description: string;
  country: string;
}

function AfriqWatchContent() {
  const searchParams = useSearchParams();
  const router = useRouter();
  const videoId = searchParams.get('videoId')?.split('-')[0]; // Extract just the ID
  const [movie, setMovie] = useState<YouTubeMovie | null>(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchMovie = async () => {
      if (videoId) {
        try {
          const response = await fetch('/data/african.json');
          const data = await response.json();
          const foundMovie = data.find((movie: YouTubeMovie) => movie.id === videoId);
          setMovie(foundMovie || null);
        } catch (error) {
          console.error('Error fetching movie:', error);
        } finally {
          setLoading(false);
        }
      }
    };

    fetchMovie();
  }, [videoId]);

  useEffect(() => {
    if (movie) {
      const formattedTitle = movie.title.toLowerCase().replace(/[^a-z0-9]+/g, '-'); // Slugify title
      const videoSlug = `${movie.id}-${formattedTitle}`;

      // If the URL is not already in the correct format, update it
      if (searchParams.get('videoId') !== videoSlug) {
        router.replace(`/watch/afriq/?videoId=${videoSlug}`);
      }
    }
  }, [movie, searchParams, router]);

  if (loading) {
    return (
      <div className="flex flex-col items-center justify-center h-screen">
        <div className="animate-shake text-6xl">
          <span role="img" aria-label="smiling emoji">
            😊
          </span>
        </div>
        <div className="mt-4 text-xl font-bold">
          Wait A Minute<span className="animated-dots">...</span>
        </div>
        <style jsx>{`
          @keyframes shake {
            0% { transform: translate(1px, 1px) rotate(0deg); }
            10% { transform: translate(-1px, -2px) rotate(-1deg); }
            20% { transform: translate(-3px, 0px) rotate(1deg); }
            30% { transform: translate(3px, 2px) rotate(0deg); }
            40% { transform: translate(1px, -1px) rotate(1deg); }
            50% { transform: translate(-1px, 2px) rotate(-1deg); }
            60% { transform: translate(-3px, 1px) rotate(0deg); }
            70% { transform: translate(3px, 1px) rotate(-1deg); }
            80% { transform: translate(-1px, -1px) rotate(1deg); }
            90% { transform: translate(1px, 2px) rotate(0deg); }
            100% { transform: translate(1px, -2px) rotate(-1deg); }
          }

          .animate-shake {
            animation: shake 0.5s infinite;
          }

          @keyframes dots {
            0%, 20% { content: "."; }
            40% { content: ".."; }
            60% { content: "..."; }
            80%, 100% { content: "...."; }
          }

          .animated-dots::after {
            content: ".";
            animation: dots 1s infinite steps(4);
          }
        `}</style>
      </div>
    );
  }

  if (!movie) {
    return <div>Movie not found</div>;
  }

  const formattedTitle = movie.title.toLowerCase().replace(/[^a-z0-9]+/g, '-');
  const videoSlug = `${movie.id}-${formattedTitle}`;
  const canonicalUrl = `https://www.delgor.com/watch/afriq?videoId=${videoSlug}`;
  const posterUrl = `https://img.youtube.com/vi/${movie.id}/hqdefault.jpg`;

  return (
    <>
      <Head>
        <title>{`${movie.title} - Watch on Delgor`}</title>
        <meta name="description" content={movie.description || "Watch this amazing African movie on Delgor"} />
        <link rel="canonical" href={canonicalUrl} />
        <meta property="og:title" content={movie.title} />
        <meta property="og:description" content={movie.description || "Watch this amazing African movie on Delgor"} />
        <meta property="og:type" content="video.movie" />
        <meta property="og:url" content={canonicalUrl} />
        <meta property="og:image" content={posterUrl} />
        <meta property="og:image:alt" content={`${movie.title} Poster`} />
        <meta property="og:site_name" content="Delgor" />
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": "Movie",
            "name": movie.title,
            "description": movie.description || "Watch this amazing African movie on Delgor",
            "image": posterUrl,
            "url": canonicalUrl,
          })}
        </script>
      </Head>
      <HeroAfric movie={movie} />
      <div className="p-8">
        <AfriqWatchButton videoId={movie.id} title={movie.title} />

        {/* AdSense Ad after Watch Button */}
        <div className="my-8">
          <AdSense />
        </div>

        <RelatedAfricanMovies videoId={movie.id} />

        {/* AdSense Ad after Related Movies */}
        <div className="my-8">
          <AdSense />
        </div>
      </div>
    </>
  );
}

export default function AfriqWatchPage() {
  return (
    <Suspense fallback={<div>Loading movie data...</div>}>
      <AfriqWatchContent />
    </Suspense>
  );
}
